==> igniteui-react-charts-16.6.4.tgz: package/ES5/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-react-core/ES5/type";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-react-core/ES5/List$1";
var CustomIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(CustomIndicator, _super);
    function CustomIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.qp = null;
        _this.qo = null;
        return _this;
    }
    CustomIndicator.prototype.get_p3 = function () {
        return new CustomIndicatorStrategy();
    };
    Object.defineProperty(CustomIndicator.prototype, "p3", {
        get: function () {
            return this.get_p3();
        },
        enumerable: true,
        configurable: true
    });
    CustomIndicator.prototype.get_qg = function () {
        return CustomIndicator.$;
    };
    Object.defineProperty(CustomIndicator.prototype, "qg", {
        get: function () {
            return this.get_qg();
        },
        enumerable: true,
        configurable: true
    });
    CustomIndicator.prototype.pf = function (a, b) {
        var e_1, _a;
        var c = this.mb(a, b);
        var d = this.mc(c);
        var e = new List$1(String_$type, 0);
        if (this.qo != null) {
            var f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
            this.qo(this, f);
            if (f.basedOn != null) {
                try {
                    for (var _b = tslib_1.__values(fromEnum(f.basedOn)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var g = _c.value;
                        e.add(g);
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
        }
        return e;
    };
    Object.defineProperty(CustomIndicator.prototype, "indicator", {
        get: function () {
            return this.qp;
        },
        set: function (a) {
            this.qp = a;
            this.pn();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CustomIndicator.prototype, "basedOnColumns", {
        get: function () {
            return this.qo;
        },
        set: function (a) {
            this.qo = a;
        },
        enumerable: true,
        configurable: true
    });
    CustomIndicator.prototype.pc = function (a, b) {
        _super.prototype.pc.call(this, a, b);
        if (this.qp != null) {
            var c = this.mb(a, b);
            if (b == 0) {
                return false;
            }
            if (!this.m8(this.pf(a, b))) {
                return false;
            }
            this.qp(this, new FinancialEventArgs(a, b, c, this.mc(c), this));
            if (this.p5(c) && this.mk != null) {
                this.mk.ck();
            }
            return true;
        }
        return false;
    };
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
}(StrategyBasedIndicator));
export { CustomIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-react-core/ES5/type";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-react-core/ES5/List$1";
/**
 * @hidden
 */
var CustomIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(CustomIndicator, _super);
    function CustomIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.qr = null;
        _this.qq = null;
        return _this;
    }
    CustomIndicator.prototype.get_p5 = function () {
        return new CustomIndicatorStrategy();
    };
    Object.defineProperty(CustomIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    CustomIndicator.prototype.get_qi = function () {
        return CustomIndicator.$;
    };
    Object.defineProperty(CustomIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    CustomIndicator.prototype.ph = function (a, b) {
        var e_1, _a;
        var c = this.md(a, b);
        var d = this.me(c);
        var e = new List$1(String_$type, 0);
        if (this.qq != null) {
            var f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
            this.qq(this, f);
            if (f.basedOn != null) {
                try {
                    for (var _b = tslib_1.__values(fromEnum(f.basedOn)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var g = _c.value;
                        e.add(g);
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
        }
        return e;
    };
    Object.defineProperty(CustomIndicator.prototype, "indicator", {
        get: function () {
            return this.qr;
        },
        set: function (a) {
            this.qr = a;
            this.pp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CustomIndicator.prototype, "basedOnColumns", {
        get: function () {
            return this.qq;
        },
        set: function (a) {
            this.qq = a;
        },
        enumerable: true,
        configurable: true
    });
    CustomIndicator.prototype.pe = function (a, b) {
        _super.prototype.pe.call(this, a, b);
        if (this.qr != null) {
            var c = this.md(a, b);
            if (b == 0) {
                return false;
            }
            if (!this.na(this.ph(a, b))) {
                return false;
            }
            this.qr(this, new FinancialEventArgs(a, b, c, this.me(c), this));
            if (this.p7(c) && this.mm != null) {
                this.mm.ck();
            }
            return true;
        }
        return false;
    };
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
}(StrategyBasedIndicator));
export { CustomIndicator };
